==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/ItemAnalytics.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import odata.msgraph.client.beta.entity.collection.request.ItemActivityStatCollectionRequest;
import odata.msgraph.client.beta.entity.request.ItemActivityStatRequest;

@JsonPropertyOrder({
    "@odata.type"})
@JsonInclude(Include.NON_NULL)
public class ItemAnalytics extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.itemAnalytics";
    }

    protected ItemAnalytics() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderItemAnalytics() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public ItemAnalytics build() {
            ItemAnalytics _x = new ItemAnalytics();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.itemAnalytics";
            _x.id = id;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @NavigationProperty(name="itemActivityStats")
    @JsonIgnore
    public ItemActivityStatCollectionRequest getItemActivityStats() {
        return new ItemActivityStatCollectionRequest(
                        contextPath.addSegment("itemActivityStats"));
    }

    @NavigationProperty(name="allTime")
    @JsonIgnore
    public ItemActivityStatRequest getAllTime() {
        return new ItemActivityStatRequest(contextPath.addSegment("allTime"));
    }

    @NavigationProperty(name="lastSevenDays")
    @JsonIgnore
    public ItemActivityStatRequest getLastSevenDays() {
        return new ItemActivityStatRequest(contextPath.addSegment("lastSevenDays"));
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ItemAnalytics patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        ItemAnalytics _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ItemAnalytics put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        ItemAnalytics _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private ItemAnalytics _copy() {
        ItemAnalytics _x = new ItemAnalytics();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ItemAnalytics[");
        b.append("id=");
        b.append(this.id);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/ItemAnalytics.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.entity.collection.request.ItemActivityStatCollectionRequest;
import odata.msgraph.client.beta.entity.request.ItemActivityStatRequest;

@JsonPropertyOrder({
    "@odata.type", 
    "itemActivityStats"})
@JsonInclude(Include.NON_NULL)
public class ItemAnalytics extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.itemAnalytics";
    }

    @JsonProperty("itemActivityStats")
    protected List<ItemActivityStat> itemActivityStats;

    protected ItemAnalytics() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderItemAnalytics() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private List<ItemActivityStat> itemActivityStats;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder itemActivityStats(List<ItemActivityStat> itemActivityStats) {
            this.itemActivityStats = itemActivityStats;
            this.changedFields = changedFields.add("itemActivityStats");
            return this;
        }

        public Builder itemActivityStats(ItemActivityStat... itemActivityStats) {
            return itemActivityStats(Arrays.asList(itemActivityStats));
        }

        public ItemAnalytics build() {
            ItemAnalytics _x = new ItemAnalytics();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.itemAnalytics";
            _x.id = id;
            _x.itemActivityStats = itemActivityStats;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    public ItemAnalytics withUnmappedField(String name, Object value) {
        ItemAnalytics _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @NavigationProperty(name="allTime")
    @JsonIgnore
    public ItemActivityStatRequest getAllTime() {
        return new ItemActivityStatRequest(contextPath.addSegment("allTime"), RequestHelper.getValue(unmappedFields, "allTime"));
    }

    @NavigationProperty(name="itemActivityStats")
    @JsonIgnore
    public ItemActivityStatCollectionRequest getItemActivityStats() {
        return new ItemActivityStatCollectionRequest(
                        contextPath.addSegment("itemActivityStats"), Optional.ofNullable(itemActivityStats));
    }

    @NavigationProperty(name="lastSevenDays")
    @JsonIgnore
    public ItemActivityStatRequest getLastSevenDays() {
        return new ItemActivityStatRequest(contextPath.addSegment("lastSevenDays"), RequestHelper.getValue(unmappedFields, "lastSevenDays"));
    }

    public ItemAnalytics withItemActivityStats(List<ItemActivityStat> itemActivityStats) {
        ItemAnalytics _x = _copy();
        _x.changedFields = changedFields.add("itemActivityStats");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.itemAnalytics");
        _x.itemActivityStats = itemActivityStats;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ItemAnalytics patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        ItemAnalytics _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ItemAnalytics put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        ItemAnalytics _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private ItemAnalytics _copy() {
        ItemAnalytics _x = new ItemAnalytics();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.itemActivityStats = itemActivityStats;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ItemAnalytics[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("itemActivityStats=");
        b.append(this.itemActivityStats);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
